/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.pop3.storage;

/**
 * {@link POP3StoragePropertyNames} - Constants for POP3 storage properties.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class POP3StoragePropertyNames {

    /**
     * Initializes a new {@link POP3StoragePropertyNames}.
     */
    private POP3StoragePropertyNames() {
        super();
    }

    /**
     * The abbreviation of the storage to use;<br />
     * e.g. <code>"mailaccount"</code> to use the default mail account as storage.
     *
     * @type <code>String</code>
     */
    public static final String PROPERTY_STORAGE = "pop3.storage";

    /**
     * The path in storage to the folder/resource keeping POP3 messages;<br />
     * e.g. <code>"INBOX/My POP3 Messages"</code> inside an mail account storage.
     *
     * @type <code>String</code>
     */
    public static final String PROPERTY_PATH = "pop3.path";

    /**
     * The refresh rate in minutes when a new connection to actual POP3 account is (possibly) allowed.
     *
     * @type <code>Integer</code>
     */
    public static final String PROPERTY_REFRESH_RATE = "pop3.refreshrate";

    /**
     * The last-accessed time stamp the last access to actual POP3 account took place.
     *
     * @type <code>Long</code>
     */
    public static final String PROPERTY_LAST_ACCESSED = "pop3.lastaccess";

    /**
     * Whether to only retrieve (<code>"false"</code>) or to retrieve-and-delete (<code>"true"</code>) messages from POP3 account.
     *
     * @type <code>Boolean</code>
     */
    public static final String PROPERTY_EXPUNGE = "pop3.expunge";

    /**
     * Whether a delete operation performed on storage also deletes affected message in POP3 account.
     *
     * @type <code>Boolean</code>
     */
    public static final String PROPERTY_DELETE_WRITE_THROUGH = "pop3.deletewt";

}
